# Euclipy

[![PyPI version](https://img.shields.io/pypi/v/euclipy.svg?color=dodgerblue&label=%20latest%20version)](https://pypi.org/project/euclipy/)
[![PyPI downloads](https://img.shields.io/pypi/dm/euclipy.svg?color=limegreen&label=PyPI%20downloads)](https://pypi.org/project/euclipy/)

### A library used to create, model, and solve figures in Euclidean Geometry.
## Features:

- Complete missing information found in triangles
```sh
# PyPi Instillation
pip install euclipy
```
